diff --git a/geomagio/metadata/Flag.py b/geomagio/metadata/Flag.py
index 327e2c1f2d1395319c8e6ecd7fe263c55d2391d4..716be182d86069e861be3515de0b8ba3011adbab 100644
--- a/geomagio/metadata/Flag.py
+++ b/geomagio/metadata/Flag.py
@@ -97,7 +97,9 @@ class Gap(Flag):
 
 class EventType(str, Enum):
     GEOMAGNETIC_STORM = "GEOMAGNETIC_STORM"
+    GEOMAGNETIC_SUBSTORM = "GEOMAGNETIC_SUBSTORM"
     EARTHQUAKE = "EARTHQUAKE"
+    OTHER = "OTHER"
 
 
 class Event(Flag):
@@ -109,16 +111,16 @@ class Event(Flag):
     event_type : EventType
         The type of event.
     scale : str
-        Geomagnetic storm scale denoted by G followed by a number 1 through 5.
-    Kp : int
-        Planetary K-index denoted by a number 1 through 10
+        Geomagnetic storm scale or Richter scale magnitude.
+    index : int
+        Planetary K-index, DST index or some other index.
     url : str
-        A url related to the event. Could be NOAA SWPC or USGS Earthquakes page.
+        A url related to the event. Could be NOAA SWPC, USGS Earthquakes page or another site.
     """
 
     event_type: EventType
     scale: str = None
-    Kp: int = None
+    index: int = None
     url: str = None